============
Port Checker
============


.. image:: https://img.shields.io/pypi/v/port_checker.svg
        :target: https://pypi.python.org/pypi/port_checker

.. image:: https://img.shields.io/travis/virogenesis/port_checker.svg
        :target: https://travis-ci.org/virogenesis/port_checker

.. image:: https://readthedocs.org/projects/port-checker/badge/?version=latest
        :target: https://port-checker.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/virogenesis/port_checker/shield.svg
     :target: https://pyup.io/repos/github/virogenesis/port_checker/
     :alt: Updates



The idea behind this command line tool is to check if a port is open on a host.
Really, really

* Free software: MIT license
* Documentation: https://port-checker.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
